==> milter-greylist_3.0.orig.tar.gz: milter-greylist-3.0/dump.h <==
/* $Id: dump.h,v 1.13.2.1 2006/09/04 22:05:59 manu Exp $ */

/*
 * Copyright (c) 2004 Emmanuel Dreyfus
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *        This product includes software developed by Emmanuel Dreyfus
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,  
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _DUMP_H_
#define _DUMP_H_

#include "config.h"
#ifdef HAVE_OLD_QUEUE_H
#include "queue.h"
#else
#include <sys/queue.h>
#endif 

#include <stdio.h>
#include <pthread.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#ifndef DUMPFILE
#define DUMPFILE "/var/milter-greylist/greylist.db"
#endif

#ifndef DUMPFREQ
#define DUMPFREQ 600
#endif

/* 
 * Maximum e-mail length, according to RFC 2821
 * <?"?local-part"?@domain>?
 * local-part maximum length is 64 chars
 * domain maximum length is 255 chars
 * Total: 324
 */
#define ADDRLEN	324
#define DATELEN 40
#define IPADDRLEN sizeof("255.255.255.255")

#include "milter-greylist.h"

extern FILE *dump_in;
extern int dump_dirty;
extern int dump_line;
extern char *dumpfile;
extern int dump_dirty;

void dump_init(void);
void *dumper(void *);
void dumper_start(void);
void dump_flush(void);
void dump_reload(void);
void dump_header(FILE *);
void dump_perform(void);

#endif /* _DUMP_H_ */

==> milter-greylist_4.2~b1.orig.tar.gz: milter-greylist-4.2b1/dump.h <==
/* $Id: dump.h,v 1.13 2006/08/30 04:57:58 manu Exp $ */

/*
 * Copyright (c) 2004 Emmanuel Dreyfus
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *        This product includes software developed by Emmanuel Dreyfus
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,  
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _DUMP_H_
#define _DUMP_H_

#include "config.h"
#ifdef HAVE_OLD_QUEUE_H
#include "queue.h"
#else
#include <sys/queue.h>
#endif 

#include <stdio.h>
#include <pthread.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#ifndef DUMPFILE
#define DUMPFILE "/var/milter-greylist/greylist.db"
#endif

#ifndef DUMPFREQ
#define DUMPFREQ 600
#endif

/* 
 * Maximum e-mail length, according to RFC 2821
 * <?"?local-part"?@domain>?
 * local-part maximum length is 64 chars
 * domain maximum length is 255 chars
 * Total: 324
 */
#define ADDRLEN	324
#define DATELEN 40
#define IPADDRLEN sizeof("255.255.255.255")

#include "milter-greylist.h"

extern FILE *dump_in;
extern int dump_line;
extern char *dumpfile;

void dump_init(void);
void *dumper(void *);
void dumper_start(void);
void dump_flush(void);
void dump_reload(void);
void dump_header(FILE *);
void dump_perform(int);
void dump_touch(int);
void dump_conf_changed(void);
void dumper_stop(void);

#endif /* _DUMP_H_ */
